SeqSrc

Enum SeqSrc 

pub enum SeqSrc<T> {
    Query(T),
    Reference(T),
}
An enum wrapping sequence data to indicate whether it represents a query sequence or a reference sequence.

Wrapping a sequence in SeqSrc is common for alignment algorithms in Zoe, allowing the methods to know which sequence is the query and which is the reference. There are multiple equivalent ways of creating a SeqSrc, including wrapping a sequence directly and using an extension trait. For example:

let seq = Nucleotides::from(b"AGTCGCTTGCATTTAC");

// Wrap a reference to the sequence
let wrapped1 = SeqSrc::Query(&seq);
let wrapped2 = seq.as_query_src();
assert_eq!(wrapped1, wrapped2);

// Wrap the owned sequence
let wrapped3 = SeqSrc::Query(seq.clone());
let wrapped4 = seq.into_query_src();
assert_eq!(wrapped3, wrapped4)

Variants



Query(T)

A query sequence of type T.



Reference(T)

A reference sequence of type T.

Implementations

Source

impl<T> SeqSrc<T>

pub fn map<U, F>(self, f: F) -> SeqSrc<U>
where F: FnOnce(T) -> U,

Maps the stored sequence via a closure, preserving whether it is a Query or Reference.

pub fn is_query(&self) -> bool

Returns whether the sequence is a query sequence.

pub fn is_reference(&self) -> bool

Returns whether the sequence is a reference sequence.