SharedProfiles

Struct SharedProfiles 

pub struct SharedProfiles<'a, const M: usize, const N: usize, const O: usize, const S: usize> { /* private fields */ }
A lazily-evaluated set of striped alignment profiles which can be shared across threads.

This is an abstraction around StripedProfile, providing convenience methods for automatically increasing the integer width and rerunning the alignment when overflow occurs. This only supports the unsigned version of the algorithm.

When sharing between threads is not needed, consider using LocalProfiles instead.

Parameters

  • 'a: The lifetime of the stored sequence, the WeightMatrix, and the alphabet (ByteIndexMap). An owned sequence can also be stored.
  • M: The number of SIMD lanes for i8 profiles
  • N: The number of SIMD lanes for i16 profiles
  • O: The number of SIMD lanes for i32 profiles
  • S: The size of the alphabet (usually 5 for DNA including N)

Implementations

Source

impl<'a, const M: usize, const N: usize, const O: usize, const S: usize> SharedProfiles<'a, M, N, O, S>

pub fn new( seq: impl Into<Cow<'a, [u8]>>, matrix: &'a WeightMatrix<'a, i8, S>, gap_open: i8, gap_extend: i8, ) -> Result<Self, ProfileError>

Creates an empty SharedProfiles.

Usually you instead want to use new_with_w128, new_with_w256, or new_with_w512, based on the SIMD register width of your target. See Picking the Register Width for more details.

Errors
Source

impl<'a, const S: usize> SharedProfiles<'a, 16, 8, 4, S>

pub fn new_with_w128( seq: impl Into<Cow<'a, [u8]>>, matrix: &'a WeightMatrix<'_, i8, S>, gap_open: i8, gap_extend: i8, ) -> Result<SharedProfiles<'a, 16, 8, 4, S>, ProfileError>

Creates an empty SharedProfiles optimized for 128-bit SIMD width.

This sets M=16, N=8, and O=4 for i8, i16, and i32 profiles respectively.

Errors

Same as SharedProfiles::new.

Source

impl<'a, const S: usize> SharedProfiles<'a, 32, 16, 8, S>

pub fn new_with_w256( seq: impl Into<Cow<'a, [u8]>>, matrix: &'a WeightMatrix<'_, i8, S>, gap_open: i8, gap_extend: i8, ) -> Result<SharedProfiles<'a, 32, 16, 8, S>, ProfileError>

Creates an empty SharedProfiles optimized for 256-bit SIMD width.

This sets M=32, N=16, and O=8 for i8, i16, and i32 profiles respectively.

Errors

Same as SharedProfiles::new.

Source

impl<'a, const S: usize> SharedProfiles<'a, 64, 32, 16, S>

pub fn new_with_w512( seq: impl Into<Cow<'a, [u8]>>, matrix: &'a WeightMatrix<'_, i8, S>, gap_open: i8, gap_extend: i8, ) -> Result<SharedProfiles<'a, 64, 32, 16, S>, ProfileError>

Creates an empty SharedProfiles optimized for 512-bit SIMD width.

This sets M=64, N=32, and O=16 for i8, i16, and i32 profiles respectively.

Errors

Same as SharedProfiles::new.