Trait AlignmentComposition

pub trait AlignmentComposition: Sealed {
    // Provided method
    fn per_site_counts<T>(&mut self) -> Option<Vec<NucleotideCounts<T>>>
       where Self: Sized + Iterator,
             Self::Item: IntoIterator<Item = u8> + Sized,
             T: Uint { ... }
}
Extension trait to allow a per-site vector of NucleotideCounts to be generated from an iterator of sequences, where the sequences are assumed to be from the same multiple sequence alignment.

Provided Methods

fn per_site_counts<T>(&mut self) -> Option<Vec<NucleotideCounts<T>>>
where Self: Sized + Iterator, Self::Item: IntoIterator<Item = u8> + Sized, T: Uint,

Gets a per-site vector of NucleotideCounts from an iterator of sequences, where the sequences are assumed to be from the same multiple sequence alignment.

Implementors

Source

impl<I: Iterator + Sealed> AlignmentComposition for I