AlignmentAndSeqs

Struct AlignmentAndSeqs 

pub struct AlignmentAndSeqs<Score, Seq> {
    pub alignment: Alignment<Score>,
    pub query: Seq,
    pub reference: Seq,
}
Available on crate feature fuzzing only.
A struct containing an Alignment along with the corresponding sequences.

Fields

alignment: Alignment<Score>

The alignment struct.

query: Seq

The query sequence, which is the same length as alignment.query_len.

reference: Seq

The reference sequence, which is the same length as alignment.ref_len.