FastQSpecs

Struct FastQSpecs 

pub struct FastQSpecs {
    pub header_specs: StringSpecs,
    pub sequence_specs: NucleotidesSpecs,
    pub same_lengths: bool,
}
Available on crate feature fuzzing only.
Specifications for generating an arbitrary FastQ record.

Fields

header_specs: StringSpecs

The specifications for generating the header.

sequence_specs: NucleotidesSpecs

The specifications for generating the sequence.

same_lengths: bool

Whether to enforce that the sequence and the quality scores are the same length.

Implementations

Source

impl FastQSpecs

pub fn parsable_fastq() -> Self

A constructor for FastQSpecs that ensures the generated FastQ can be parsed by FastQReader.

This includes ensuring that the header only contains graphic ASCII or spaces, that the sequence only contains graphic ASCII, and that the sequence and quality scores are the same length.