pub struct SAMReader<R: Read, const OPT: bool> { /* private fields */ }Expand description
An iterator for buffered reading of a SAM file.
This iterator guarantees quality scores are valid (see QualityScores for
more details). It does not check for the validity of the CIGAR strings.
Parameters
R: The type of the underlying readerOPT: Whether optional fields should be parsed
Implementations
Sourceimpl<R: Read> SAMReader<R, true>
impl<R: Read> SAMReader<R, true>
Sourcepub fn new(inner: R) -> Self
pub fn new(inner: R) -> Self
Creates an iterator over SAM data, wrapping the input in a buffered reader.
Unlike from_readable, this does not read any data initially. It also
allows for empty input, in which case the resulting iterator is empty.
If the optional data in the SAM records is not being used by the
downstream application, consider using new_ignore_opt for
efficiency.
Sourcepub fn from_readable(read: R) -> Result<Self>
pub fn from_readable(read: R) -> Result<Self>
Creates an iterator over SAM data from a type implementing Read,
wrapping the input in a buffered reader.
If the optional data in the SAM records is not being used by the
downstream application, consider using from_readable_ignore_opt for
efficiency.
Errors
Will return Err if the input data is empty or an IO error occurs.
Sourceimpl<R: Read> SAMReader<R, false>
impl<R: Read> SAMReader<R, false>
👎Deprecated since 0.0.29: please use new_ignore_opt instead. This function will be removed in v0.0.31
please use new_ignore_opt instead. This function will be removed in v0.0.31
Deprecated, use new_ignore_opt instead.
Sourcepub fn new_ignore_opt(inner: R) -> Self
pub fn new_ignore_opt(inner: R) -> Self
Creates an iterator over SAM data, wrapping the input in a buffered reader.
This version ignores any optional data present in the SAM records in
order to reduce allocations and improve efficiency. Use new to
include the optional data in the output.
Unlike from_readable_ignore_opt, this does not read any data
initially. It also allows for empty input, in which case the resulting
iterator is empty.
👎Deprecated since 0.0.29: please use from_readable_ignore_opt instead. This function will be removed in v0.0.31
please use from_readable_ignore_opt instead. This function will be removed in v0.0.31
Deprecated, use from_readable_ignore_opt instead.
Sourcepub fn from_readable_ignore_opt(read: R) -> Result<Self>
pub fn from_readable_ignore_opt(read: R) -> Result<Self>
Creates an iterator over SAM data from a type implementing Read,
wrapping the input in a buffered reader.
This version ignores any optional data present in the SAM records in
order to reduce allocations and improve efficiency. Use
from_readable to include the optional data in the output.
Errors
Will return Err if the input data is empty or an IO error occurs.
Sourceimpl SAMReader<File, true>
impl SAMReader<File, true>
Sourcepub fn from_path<P>(path: P) -> Result<Self, Error>
pub fn from_path<P>(path: P) -> Result<Self, Error>
Creates an iterator over the SAM data contained in a path, using a buffered reader.
If the optional data in the SAM records is not being used by the
downstream application, consider using from_path_ignore_opt for
efficiency.
Errors
Will return Err if the path does not exist, if there are insufficient
permissions to read from it, or if it contains no data. The path is
included in the error message.
Sourceimpl SAMReader<File, false>
impl SAMReader<File, false>
👎Deprecated since 0.0.29: please use from_path_ignore_opt instead. This function will be removed in v0.0.31
please use from_path_ignore_opt instead. This function will be removed in v0.0.31
Deprecated, use from_path_ignore_opt instead.
Sourcepub fn from_path_ignore_opt<P>(path: P) -> Result<Self, Error>
pub fn from_path_ignore_opt<P>(path: P) -> Result<Self, Error>
Creates an iterator over the SAM data contained in a path, using a buffered reader.
This version ignores any optional data present in the SAM records in
order to reduce allocations and improve efficiency. Use from_path to
include the optional data in the output.
Errors
Will return Err if the path does not exist, if there are insufficient
permissions to read from it, or if it contains no data. The path is
included in the error message.