Trait CheckSequence

pub trait CheckSequence {
    // Required methods
    fn is_ascii_simd<const N: usize>(&self) -> bool
       where LaneCount<N>: SupportedLaneCount;
    fn is_graphic_simd<const N: usize>(&self) -> bool
       where LaneCount<N>: SupportedLaneCount;
}
Provides SIMD-accelerated sequence validation methods.

Required Methods

fn is_ascii_simd<const N: usize>(&self) -> bool

Checks if all bytes in the sequence are ASCII using SIMD operations

fn is_graphic_simd<const N: usize>(&self) -> bool

Checks if all bytes in the sequence are printable ASCII using SIMD operations

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T> CheckSequence for T
where T: AsRef<[u8]>,