pub enum DistanceError {
NoData,
NotComparable,
}Expand description
Errors that can occur when calculating distances.
Variants
NoData
No data found in at least one function argument.
NotComparable
Data only had invalid state that was not able to be compared.