pub enum SeqSrc<T> {
Query(T),
Reference(T),
}Expand description
An enum wrapping sequence data to indicate whether it represents a query sequence or a reference sequence.
Wrapping a sequence in SeqSrc is common for alignment algorithms in
Zoe, allowing the methods to know which sequence is the query and which is
the reference. There are multiple equivalent ways of creating a SeqSrc,
including wrapping a sequence directly and using an extension trait. For
example:
let seq = Nucleotides::from(b"AGTCGCTTGCATTTAC");
// Wrap a reference to the sequence
let wrapped1 = SeqSrc::Query(&seq);
let wrapped2 = seq.as_query_src();
assert_eq!(wrapped1, wrapped2);
// Wrap the owned sequence
let wrapped3 = SeqSrc::Query(seq.clone());
let wrapped4 = seq.into_query_src();
assert_eq!(wrapped3, wrapped4)Variants
Implementations