pub struct FastQSpecs {
pub header_specs: StringSpecs,
pub sequence_specs: NucleotidesSpecs,
pub same_lengths: bool,
}Available on crate feature
fuzzing only.Expand description
Specifications for generating an arbitrary FastQ record.
Fields
header_specs: StringSpecsThe specifications for generating the header.
sequence_specs: NucleotidesSpecsThe specifications for generating the sequence.
same_lengths: boolWhether to enforce that the sequence and the quality scores are the same length.
Implementations
Sourceimpl FastQSpecs
impl FastQSpecs
Sourcepub fn parsable_fastq() -> Self
pub fn parsable_fastq() -> Self
A constructor for FastQSpecs that ensures the generated FastQ
can be parsed by FastQReader.
This includes ensuring that the header only contains graphic ASCII or spaces, that the sequence only contains graphic ASCII, and that the sequence and quality scores are the same length.