pub trait DisplayErrStack {
// Required method
fn display_stack(&self) -> ErrStackDisplay<'_>;
}Expand description
An extension trait for an Error enabling it to be displayed alongside
its error stack using Error::source.
If aborting, consider using fail or die. Otherwise, this can be
helpful in displaying warnings.
Required Methods
Sourcefn display_stack(&self) -> ErrStackDisplay<'_>
fn display_stack(&self) -> ErrStackDisplay<'_>
Returns a displayable representation of the error alongside its error
stack using Error::source.
This using → and two spaces of indent before each item, and includes a
newline at the end.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".