pub trait CheckSequence {
// Required methods
fn is_ascii_simd<const N: usize>(&self) -> bool
where LaneCount<N>: SupportedLaneCount;
fn is_graphic_simd<const N: usize>(&self) -> bool
where LaneCount<N>: SupportedLaneCount;
}Expand description
Provides SIMD-accelerated sequence validation methods.
Required Methods
Sourcefn is_ascii_simd<const N: usize>(&self) -> boolwhere
LaneCount<N>: SupportedLaneCount,
fn is_ascii_simd<const N: usize>(&self) -> boolwhere
LaneCount<N>: SupportedLaneCount,
Checks if all bytes in the sequence are ASCII using SIMD operations
Sourcefn is_graphic_simd<const N: usize>(&self) -> boolwhere
LaneCount<N>: SupportedLaneCount,
fn is_graphic_simd<const N: usize>(&self) -> boolwhere
LaneCount<N>: SupportedLaneCount,
Checks if all bytes in the sequence are printable ASCII using SIMD operations
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.